% This script creates a new flow field
% We need to initialize U1, U2, U3, TH and P

% Since we are starting with a new flow, set TIME_STEP=0
% If you are continuing an existing simulation, don't do this (unless you want to reset the timestep)
TIME_STEP=0;

U1=zeros(NX,NY); % U1 is the velocity in the X direction
U2=zeros(NX,NY); % U2 is the velocity in the Y direction
U3=zeros(NX,NY); % U3 is the velocity in the Z direction
P=zeros(NX,NY); % P is the pressure
PHI=zeros(NX,NY); % PHI is a temporary variable used to make the velocity divergence free

TH=zeros(NX,NY,1:N_TH);

% Lock exchange
%for i=1:NX
%for j=1:NY
%  TH(i,j,:)=1-tanh(10*(GXF(i)-LX/4)); 
%end
%end

% Rossby wave: Geostrophic balance
%U1(ii,jj)=-(1/I_RO)*0.5*((P(ii,jp)-P(ii,jm))./(DY(ii,jp)+DY(ii,jj)) ...
%                        +(P(im,jp)-P(im,jm))./(DY(im,jp)+DY(im,jj)));
%U2(ii,jj)=(1/I_RO)*0.5*((P(ip,jj)-P(im,jj))./(DX(ip,jj)+DX(ii,jj)) ...
%                       +(P(ip,jm)-P(im,jm))./(DX(ip,jm)+DX(ii,jm))); 

%P=zeros(NX,NY);

% Bubble drop
%for i=1:NX
%for j=1:NY
%    TH(i,j,:)=exp(-(GXF(i)-LX/2)^2*40-(GYF(j)-LY/2)^2*40);
%end
%end

% Channel flow
%for i=1:NX
%  U1(i,1:NY)=160*(LY/4-((GYF-LY/2).^2));
%  U1(i,1:NY)=exp(-((GYF-LY/2)/0.5).^2);
%  TH(i,1:NY,1)=GYF;
%end

% Ekman layer
% Use a lower Reynolds number to spread the Ekman layer in depth
depth=GYF-GYF(end); % Create a depth coordinate
rho0=1000; % Set Boussinesq density
tau_x=U1_BC_YMAX_C1(1)/Re*rho0;
tau_y=U3_BC_YMAX_C1(1)/Re*rho0;
delta=sqrt(2/I_RO/Re); % Laminar Ekman layer depth
delta=0.2*sqrt(sqrt(tau_x^2+tau_y^2)/rho0)/I_RO; % Turbulent Ekman layer depth
for i=1:NX
  U1(i,1:NY)=sqrt(2)/rho0/I_RO/delta*exp(depth/delta) ...
         .*(tau_x*cos(depth/delta-pi/4)-tau_y*sin(depth/delta-pi/4));
  U3(i,1:NY)=-sqrt(2)/rho0/I_RO/delta*exp(depth/delta) ...
         .*(tau_x*sin(depth/delta-pi/4)+tau_y*cos(depth/delta-pi/4));
  TH(i,1:NY,1)=GYF/GYF(end);
end


% For random Fourier noise
%for i1=1:5
%    for j1=1:5
%        kx=i1*2*pi/LX;
%        ky=j1*2*pi/LY;
%        A1=0.2*rand;
%        A2=0.2*rand;
%        A3=0.2*rand;
%        A4=0.2*rand;
%        CS1=rand*2*pi;
%        CS2=rand*2*pi;
%        CS3=rand*2*pi;
%        CS4=rand*2*pi;
%        CC1=rand*2*pi;
%        CC2=rand*2*pi;
%        CC3=rand*2*pi;
%        CC4=rand*2*pi;
%        for i=1:NX
%        for j=1:NY
%          TH(i,j,1)=TH(i,j,1)+A1*sin(kx*GXF(i)+CS1)*sin(ky*GYF(j)+CC1);
%          TH(i,j,1)=TH(i,j,1)+A2*sin(kx*GXF(i)+CS2)*cos(ky*GYF(j)+CC2);
%          TH(i,j,1)=TH(i,j,1)+A3*cos(kx*GXF(i)+CS3)*sin(ky*GYF(j)+CC3);
%          TH(i,j,1)=TH(i,j,1)+A4*cos(kx*GXF(i)+CS4)*cos(ky*GYF(j)+CC4);
%        end
%        end
%    end
%end


%TH(:,:,1)=1-2*rand([NX,NY]);

% Kelvin-Helmholtz instability
% Use a domain size LY=1;
%for i=1:NX
%for j=1:NY
%  TH(i,j,:)=-tanh(40*(GYF(j)-LY/2)); 
%  U1(i,j)=2*tanh(40*(GYF(j)-LY/2)); 
%end
%end
% Add a random perturbation to the velocity
U1=U1+0.01*(rand(NX,NY)-0.5);
U2=U2+0.01*(rand(NX,NY)-0.5);
U3=U3+0.01*(rand(NX,NY)-0.5);

% For Rossby wave case (working)
% Set LX=1, LY=1, I_RO=10
% Here, beta=1, |k^2|=315.8, and cp_x=-beta/|k^2|=-0.0032
% kx=2*2*pi/LX;
% ky=2*2*pi/LY;
% for i=1:NX
% for j=1:NY
% psi(i,j)=0.001*sin(kx*GXF(i))*cos(ky*GYF(j))*exp(-(GYF(j)-LY/2)^2/(LY/20));
% end
% end
% U1(ii,jj)=-real((psi(ip,jj)-psi(ii,jj))./DXF(ii,jj));
% U2(ii,jj)=real((psi(ii,jp)-psi(ii,jj))./DYF(ii,jj));
% % Ensure that the fields are periodic in x
% U1(NX,jj)=U1(3,jj); 
% U1(2,jj)=U1(NX-1,jj);
% U2(NX,jj)=U2(3,jj);
% U2(2,jj)=U2(NX-1,jj);
% for j=1:NY
%   CORI_Z(:,j)=1+0.1*((GYF(j)-(LY/2)))/LY; % Add a linear gradient to the rotation rate
% end


