
% This file contains definitions for various physical and runtime paramters.

% Physical paramters:
Re=10000;			% Reynolds number
LX=200;			% x - Domain size
LY=100;				% y - Domain size

% In some applications, we don't want to allow velocity in/out of the 2D plane
% Specify whether to timestep U3 using this flag: (0=FALSE, 1=TRUE)
SOLVE_U3=1;

% Number of gridpoints 
% Note - Since there are 2 ghost cells in each direction, there will be (NX-2)*(NY-2) computational gridpoints
NX=256;
NY=128;

% The number of active/passive scalars
N_TH=1;			

% Set the following parameters for each of the scalars
for n=1:N_TH
  PR(n)=1.0;		% Prandtl (or Schmidt) number
  RI(n)=0.0;		% Richardson number (for buoyancy) 
end 

% Specify the direction of the gravitational unit vector 
% (Do for each scalar, but these are probably the same!) 
for n=1:N_TH
  GRAV_X(n)=0;
  GRAV_Y(n)=0;
  GRAV_Z(n)=0;
end
% Optionally, specify background horizontal gradients for each scalar
for n=1:N_TH
  DTHDX(n)=0;
  DTHDY(n)=0;
  DTHDZ(n)=0;
end

% External body force  (can be scalars or NX,NY matrices)
FORCE_X=0;
FORCE_Y=0;
FORCE_Z=0;

% Parameters for rotating flows - for no rotation, set I_RO=0;
% The magnitude of the Coriolis parameter is set using 1/Rossby number
% The direction of the rotation vector is set by a unit vector CORI
% The arrays CORI_X, etc. can be spatially varying to account for the Beta effect.
I_RO=1e-4;                     % 1/Rossby number
CORI_X=zeros(NX,NY);		% x-component of the Coriolis unit vector
CORI_Y=ones(NX,NY);	   		% x-component of the Coriolis unit vector
CORI_Z=zeros(NX,NY);		% x-component of the Coriolis unit vector

% Runtime parameters:
N_TIME_STEPS=100000; 	% Number of timesteps
VARIABLE_DT=1;		% 1=Use CFL number to set variable timestep
			% 0=Use DELTA_T for constant timestep
DELTA_T=0.001;		% When using a fixed timestep (VARIABLE_DT=0), this is the timestep size
CFL=1.0;		% When using a variable timestep (VARIABLE_DT=1), the timestep is calculated from this CFL number

N_DISP_FLOW=5;         % Specify how often (in timesteps) to call display_flow
N_SAVE_FLOW=100;         % Specify how often (in timesteps) to save flow fields
N_SAVE_STATS=5;         % Specify how often (in timesteps) to calculate and save flow statistics

tol=1e-6;           % Set the error tolerance for the iterative solvers

% The following are the sizes of each Runge-Kutta substep - don't change these values!
H_BAR(1)=DELTA_T*(8/15);
H_BAR(2)=DELTA_T*(2/15);
H_BAR(3)=DELTA_T*(5/15);
BETA_BAR(1)=1.0;
BETA_BAR(2)=25.0/8.0;
BETA_BAR(3)=9.0/4.0;
ZETA_BAR(1)=0.0;
ZETA_BAR(2)=-17.0/8.0;
ZETA_BAR(3)=-5.0/4.0;



